#! /bin/sh
#
# /etc/rc.d/rc.S  This file is executed by init(8) when the system boots
#

export PATH=/bin:/usr/bin:/sbin:/usr/sbin
export HOME=/root
export TERM=linux

# XXX Check, if we could get along without this...
export MM_RUNASROOT=true

umask 022

# Configure the system clock. See /usr/doc/ktzset. Replaces /sbin/clock -s
if test -x /sbin/kern_tzset; then
	CONF_KERNTZ_FLAG="`get_val CONF_KERNTZ_FLAG`"
	if [ -z "$CONF_KERNTZ_FLAG" ]; then
		/sbin/kern_tzset
	else
		/sbin/kern_tzset -${CONF_KERNTZ_FLAG}
	fi
fi

# Check the integrity of all filesystems.
# If there was a failure, drop into single-user mode
fsck -A -a
if [ $? -gt 1 ]; then
	echo
	echo "**************************************"
	echo "Filesystemcheck failed. Please reboot."
	echo "**************************************"
	echo
	sh
fi

# Remount the root filesystem in read-write mode.
mount -n -o remount /

# Remove any lockfile and the mount table, so that 'mount' will recreate
# the mount table with a root entry.
rm -f /etc/mtab~ /etc/mtab

# Mount filesystems in '/etc/fstab' (and create an entry for /),
# but not NFS because TCP/IP is not yet configured.
mount -avt nonfs
chmod 644 /etc/mtab
chown root.root /etc/mtab

# Fire up bdflush/update daemons.
update

# special handling for umsdos root partition. sfgrep is a small fgrep
if mount | sfgrep ' / type umsdos ' >/dev/null ; then
	/sbin/umssync -r99 -v- / >/dev/null 2>&1
fi

# minimal route to loopback
ifconfig lo 127.0.0.1
route add 127.0.0.1

# set hostname
HOSTNAME="`get_val CONF_NODENAME`"
if [ -n "$HOSTNAME" ]; then
	hostname $HOSTNAME
else
	hostname lstlinux
fi
echo "nodename: `hostname`"

# Remove stale locks.
rm -f /var/spool/locks/* /var/spool/uucp/LCK..* /var/lock/LCK..* /tmp/.X*lock
rm -f /etc/nologin

# Enable swapping.
swapon -a

# Init PCMCIA
if test -x /etc/rc.d/rc.pcmcia ; then
	/etc/rc.d/rc.pcmcia autostart
fi

# Init modules
if test -x /etc/rc.d/rc.modules ; then
	/etc/rc.d/rc.modules
fi

# Initialize the NET subsystem.
if test -x /etc/rc.d/rc.inet1 ; then
	/etc/rc.d/rc.inet1
fi

# Mount any active nfs filesystems
if sfgrep nfs /etc/fstab >/dev/null ; then
	echo "Mounting remote filesystems..."
	mount -avt nfs
fi

# remove utmp after nfs mount because /var can be nfs-mounted
rm -f /var/run/utmp
cat /dev/null > /var/run/utmp
chmod 664 /var/run/utmp
chown root.tty /var/run/utmp

# Tell them what they are using
if test -r /etc/.issue; then
	cat /etc/.issue > /etc/issue
fi
# Remember to call "lisa --install" at least once
if test -r /etc/.call_lisa_note; then
	cat /etc/.call_lisa_note >> /etc/issue
fi

# Generate a new list of available shared libraries.
ldconfig -X

# Recover elvis files.
if test -x /usr/bin/elvprsv; then
	elvprsv /tmp/elv_*
fi

# Start minimal daemons.
echo -n "Starting minimal daemons:"
if test -x /sbin/syslogd; then
	echo -n " syslogd"
	/sbin/syslogd
fi
if test -x /sbin/klogd; then
	echo -n " klogd"
	/sbin/klogd
fi
if test -x /usr/sbin/portmap; then
	echo -n " portmap"
	/usr/sbin/portmap
fi
if test -x /usr/sbin/inetd; then
	echo -n " inetd"
	/usr/sbin/inetd
fi
# The cron daemon let's you start commands at specific times or intervals.
# It must be started after "/usr" has been mounted.
#
if test -x /usr/sbin/cron; then
	echo -n " cron"
	/usr/sbin/cron
fi
echo

# Start net daemons.
if test -x /etc/rc.d/rc.inet2 ; then
	/etc/rc.d/rc.inet2
fi

# The following script is executed at boot-up and also from a cron-entry
# in the early morning. So your system should be checked often enough.
#if test -x /root/bin/cron.daily; then
#	/root/bin/cron.daily
#fi

# Finally do any local stuff.
/etc/rc.d/rc.local

# End.

